# Automated Research Assistant

<b>[AutoRA](https://pypi.org/project/autora/)</b> (<b>Auto</b>mated <b>R</b>esearch <b>A</b>ssistant) is an open-source framework for 
automating multiple stages of the empirical research process, including model discovery, experimental design, data collection, and documentation for open science.

![Autonomous Empirical Research Paradigm](img/overview.png)

AutoRA implements the <b>Autonomous Empirical Research Paradigm</b>, which involves a dynamic interplay
between two artificial agents. The first agent, a theorist, is primarily responsible for constructing 
computational models by relying on existing data to link experimental conditions to dependent measures. 
The second agent, an experimentalist, is tasked with designing follow-up
experiments that can refine and validate the models generated by the theorist. Together, these agents
implement an automated scientific discovery process. To enable closed-loop empirical research, AutoRA 
interfaces with platforms for automated data collection, such as Prolific or Amazon Mechanical Turk, 
which enable the efficient acquisition of behavioral data from human participants. Finally, AutoRA 
is designed to support the automated documentation and dissemination of steps in the empirical research process.

AutoRA was initially intended for accelerating research in the behavioral and brain sciences. 
However, AutoRA is designed as a general framework that enables automation of research processes in
other empirical sciences, such as materials science or physics.

## Features

AutoRA consists of different modules that can be used independently or in combination, such as:

- [**Theorists**](theorist/index.md) that support the discovery of formal scientific models from data
- [**Experimentalists**](experimentalist/index.md) that support the design of follow-up experiments
- [**Experiment runners**](experiment-runner/index.md) that support data collection from experimentation platforms (e.g., Prolific or Amazon Mechanical Turk)
- [**Workflow logic**](user-guide/workflow) for defining interactions between different components of the research process
- <b>Interfaces for automated documentation</b> of the research process

## Uses

AutoRA can be used for a variety of research purposes in empirical sciences, such as psychology, 
neuroscience, economics, physics, or materials science. Usages, as illustrated in the following tutorials, include:

- [**Equation discovery**](tutorials/Theorist.ipynb) from empirical data
- [**Experimental design**](tutorials/Experimentalist.ipynb) for follow-up experiments
- **Research documentation and dissemination**
- **Closed-loop empirical research**
- **Computational analyses of the scientific process** (metascience, computational philosophy of science)

## Motivation

The pace of empirical research is constrained by the rate at which scientists can alternate between the development of formal theories and the execution of experiments. However, attempts to increase this rate often compromise scientific rigor, leading to deficiencies such as the absence of formal modeling, non-replicable findings, and insufficient documentation. In order to surmount these limitations, we aim to develop AutoRA––an open-source framework that automates the generation, estimation, and empirical testing of scientific models. By automating steps of the empirical research process, we hope AutoRA can accelerate scientific discovery while promoting greater transparency and rigor in empirical research.

## Pointers

- [AutoRA Pip Package](https://pypi.org/project/autora/)
- [GitHub Repository](https://github.com/AutoResearch/autora)
- [Autonomous Empirical Research Group](http://www.empiricalresearch.ai)

## About

This project is in active development by the [Autonomous Empirical Research Group](https://musslick.github.io/AER_website/Research.html), led by [Sebastian Musslick](https://smusslick.com), in collaboration with the [Center for Computation and Visualization at Brown University](https://ccv.brown.edu).

The development of this package is supported by Schmidt Science Fellows, in partnership with the Rhodes Trust, as well as the Carney BRAINSTORM program at Brown University.


